function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import { View, StyleSheet, TouchableOpacity } from "react-native";
import { FlashList } from "@shopify/flash-list";
import { useTreeViewStore } from "../store/treeView.store";
import { getFilteredTreeData, getFlattenedTreeData, getInnerMostChildrenIdsInTree, handleToggleExpand, toggleCheckboxes } from "../helpers";
import { CheckboxView } from "./CheckboxView";
import { CustomExpandCollapseIcon } from "./CustomExpandCollapseIcon";
import { defaultIndentationMultiplier } from "../constants/treeView.constants";
import { useShallow } from 'zustand/react/shallow';
const NodeList = /*#__PURE__*/React.memo(_NodeList);
export default NodeList;
function _NodeList(props) {
  const {
    treeFlashListProps,
    checkBoxViewStyleProps,
    indentationMultiplier,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent,
    CustomNodeRowComponent
  } = props;
  const {
    expanded,
    initialTreeViewData,
    updateInnerMostChildrenIds,
    searchKeys,
    searchText
  } = useTreeViewStore(useShallow(state => ({
    expanded: state.expanded,
    initialTreeViewData: state.initialTreeViewData,
    updateInnerMostChildrenIds: state.updateInnerMostChildrenIds,
    searchKeys: state.searchKeys,
    searchText: state.searchText
  })));

  // First we filter the tree as per the search term and keys
  const filteredTree = React.useMemo(() => getFilteredTreeData(initialTreeViewData, searchText.trim().toLowerCase(), searchKeys), [initialTreeViewData, searchText, searchKeys]);

  // Then we flatten the treen to make it "render-compatible" in a "flat" list
  const flattenedFilteredNodes = React.useMemo(() => getFlattenedTreeData(filteredTree, expanded), [filteredTree, expanded]);

  // And update the innermost children id -> required to un/select filtered tree
  React.useEffect(() => {
    const updatedInnerMostChildrenIds = getInnerMostChildrenIdsInTree(filteredTree);
    updateInnerMostChildrenIds(updatedInnerMostChildrenIds);
  }, [filteredTree, updateInnerMostChildrenIds]);
  const nodeRenderer = React.useCallback(({
    item
  }) => {
    return /*#__PURE__*/React.createElement(Node, {
      node: item,
      level: item.level || 0,
      checkBoxViewStyleProps: checkBoxViewStyleProps,
      indentationMultiplier: indentationMultiplier,
      CheckboxComponent: CheckboxComponent,
      ExpandCollapseIconComponent: ExpandCollapseIconComponent,
      ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent,
      CustomNodeRowComponent: CustomNodeRowComponent
    });
  }, [CheckboxComponent, ExpandCollapseIconComponent, ExpandCollapseTouchableComponent, CustomNodeRowComponent, checkBoxViewStyleProps, indentationMultiplier]);
  return /*#__PURE__*/React.createElement(FlashList, _extends({
    estimatedItemSize: 36,
    removeClippedSubviews: true,
    keyboardShouldPersistTaps: "handled",
    drawDistance: 50,
    data: flattenedFilteredNodes,
    renderItem: nodeRenderer,
    ListHeaderComponent: /*#__PURE__*/React.createElement(HeaderFooterView, null),
    ListFooterComponent: /*#__PURE__*/React.createElement(HeaderFooterView, null)
  }, treeFlashListProps));
}
;
function HeaderFooterView() {
  return /*#__PURE__*/React.createElement(View, {
    style: styles.defaultHeaderFooter
  });
}
function getValue(isChecked, isIndeterminate) {
  if (isIndeterminate) {
    return 'indeterminate';
  } else if (isChecked) {
    return true;
  } else {
    return false;
  }
}
const Node = /*#__PURE__*/React.memo(_Node);
function _Node(props) {
  const {
    node,
    level,
    checkBoxViewStyleProps,
    indentationMultiplier = defaultIndentationMultiplier,
    ExpandCollapseIconComponent = CustomExpandCollapseIcon,
    CheckboxComponent = CheckboxView,
    ExpandCollapseTouchableComponent = TouchableOpacity,
    CustomNodeRowComponent
  } = props;
  const {
    isExpanded,
    value
  } = useTreeViewStore(useShallow(state => ({
    isExpanded: state.expanded.has(node.id),
    value: getValue(state.checked.has(node.id),
    // isChecked
    state.indeterminate.has(node.id) // isIndeterminate
    )
  })));
  const _onToggleExpand = React.useCallback(() => {
    handleToggleExpand(node.id);
  }, [node.id]);
  const _onCheck = React.useCallback(() => {
    toggleCheckboxes([node.id]);
  }, [node.id]);
  if (!CustomNodeRowComponent) {
    var _node$children;
    return /*#__PURE__*/React.createElement(View, {
      style: [styles.nodeCheckboxAndArrowRow, {
        paddingStart: level * indentationMultiplier
      }]
    }, /*#__PURE__*/React.createElement(CheckboxComponent, _extends({
      text: node.name,
      onValueChange: _onCheck,
      value: value
    }, checkBoxViewStyleProps)), (_node$children = node.children) !== null && _node$children !== void 0 && _node$children.length ? /*#__PURE__*/React.createElement(ExpandCollapseTouchableComponent, {
      style: styles.nodeExpandableArrowTouchable,
      onPress: _onToggleExpand
    }, /*#__PURE__*/React.createElement(ExpandCollapseIconComponent, {
      isExpanded: isExpanded
    })) : null);
  } else {
    return /*#__PURE__*/React.createElement(CustomNodeRowComponent, {
      node: node,
      level: level,
      checkedValue: value,
      isExpanded: isExpanded,
      onCheck: _onCheck,
      onExpand: _onToggleExpand
    });
  }
}
;
const styles = StyleSheet.create({
  defaultHeaderFooter: {
    padding: 5
  },
  nodeExpandableArrowTouchable: {
    flex: 1
  },
  nodeCheckboxAndArrowRow: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
    minWidth: "100%"
  }
});
//# sourceMappingURL=NodeList.js.map